# Changelog

## Release v0.1.4

* Reader now implements protocol buffer
* Added support for new data fields
* Increased efficiency with available_fields

## Release v0.1.3

* Added non blocking thread for running web socket as background process. Resolves issue #1
* Added additional docstring documentation.
## Release v0.1.2

* Added bumpversion. 
## Release v0.1.1

Initial release.
